CREATE OR REPLACE VIEW DATA_DICTIONARY
AS
SELECT o.owner schema, o.parent_object_type parent_type,
       o.parent_object_name parent_name,
       o.object_type, o.object_name, o.status, 
       DECODE(a.temporary,'Y','Temporary',NULL) t_temporary, 
       SUBSTR(c.comments,1,1000) c_comments,
       a.num_rows t_rowcount, 
       a.last_analyzed t_last_analyzed, 
       a.partitioned t_partitioned, a.table_type t_table_of_type, 
       m.updatable m_updatable, m.rewrite_enabled m_rewrite_enabled, 
       m.rewrite_capability m_rewrite_capability,
       m.refresh_mode m_refresh_mode, 
       m.refresh_method m_refresh_method, 
       m.fast_refreshable m_fast_refreshable,
       m.last_refresh_type m_last_refresh_type, 
       m.last_refresh_date m_last_refresh_date,
       m.staleness m_staleness,  
       t.typecode y_typecode,
       l.coll_type l_coll_type, l.upper_bound l_upper_bound,
       l.elem_type_owner l_elem_type_owner, 
       l.elem_type_name l_elem_type_name, 
       s.table_owner s_table_owner, s.table_name s_table_name,
       s.db_link s_db_link,
       q.min_value q_min_value, q.max_value q_max_value,
       q.increment_by q_increment_by, 
       q.cycle_flag q_cycle_flag, q.order_flag q_order_flag, 
       q.cache_size q_cache_size, q.last_number q_last_number,
       i.index_type i_index_type, i.uniqueness i_uniqueness,
       i.compression i_compression,
       r.constraint_type r_constraint_type, 
       r.search_condition r_search_condition,
       r.r_owner r_r_owner,
       r.r_constraint_name r_r_constraint_name, 
       r.delete_rule r_delete_rule, r.validated r_validated,
       b.username b_username, b.host b_host, b.created b_created, 
       d.column_id, d.column_name, d.data_type, d.data_length, d.data_precision,
       d.data_scale, d.nullable, d.detail_type,
       userenv('SESSIONID') audsid
  FROM (SELECT xo.owner, xo.object_type parent_object_type,
               xo.object_name parent_object_name, 
               NVL2(xp.object_name,'PROCEDURE',
                 DECODE(xo.object_type,'TYPE','ATTRIBUTE',xo.object_type)) object_type, 
               NVL(xp.object_name, xo.object_name) object_name,  
               xo.status, 
               DECODE(NVL2(xp.object_name,'PROCEDURE',xo.object_type),
                      'TYPE','ATTRIBUTE','FUNCTION','ARGUMENT',
                      'PROCEDURE','ARGUMENT',
                      'CONSTRAINT','CONSCOL','COLUMN') detail_type
          FROM all_objects xo, 
               (SELECT distinct owner, object_name, package_name
                  FROM all_arguments
                 WHERE package_name IS NOT NULL) xp
         WHERE xo.object_type IN ('TABLE', 'VIEW', 'SYNONYM',
               'TYPE', 'SEQUENCE', 'FUNCTION', 'PROCEDURE',
               'PACKAGE')
           AND xo.owner=xp.owner (+)
           AND xo.object_name=xp.package_name (+)
           AND xo.generated='N'
         UNION ALL
        SELECT xc.owner, xo.object_type, xc.table_name,
               'CONSTRAINT', xc.constraint_name, xc.status,
               'CONSCOL'
          FROM all_constraints xc, all_objects xo
         WHERE xc.generated='USER NAME'
           AND xc.owner=xo.owner 
           AND xc.table_name=xo.object_name
         UNION ALL
        SELECT owner, table_type, table_name, 'INDEX',
               index_name, status, 'INDEXCOL'
          FROM all_indexes
         WHERE generated='N'
         UNION ALL
        SELECT owner, 'DB_LINK', CAST(DB_LINK AS VARCHAR2(30)), 'DB_LINK',
               CAST(DB_LINK AS VARCHAR2(30)), NULL, 'NONE'
          FROM all_db_links) o,
       all_all_tables a, all_tab_comments c, all_mviews m,
       all_types t,
       all_coll_types l, all_synonyms s, all_sequences q,
       all_indexes i, all_constraints r, all_db_links b,
                 (SELECT owner, table_name parent_object_name,
                         table_name object_name, 'COLUMN' detail_type, 
                         column_id, SUBSTR(column_name,1,32) column_name,
                         data_type, data_length, data_precision, data_scale, 
                         nullable
                    FROM all_tab_columns
                   UNION ALL
                  SELECT owner, NVL(package_name, object_name), object_name,
                         'ARGUMENT',
                         data_level*100+position, 
                         DECODE(position,0,object_name,SUBSTR(argument_name,1,32)),
                         data_type, data_length, data_precision, data_scale,
                         in_out
                    FROM all_arguments
                   UNION ALL
                  SELECT owner, type_name, type_name,
                         'ATTRIBUTE', 
                         attr_no, SUBSTR(attr_name,1,32),
                         attr_type_name, length, precision, scale,
                         attr_type_owner
                    FROM all_type_attrs 
                   UNION ALL
                  SELECT index_owner, table_name, index_name,
                         'INDEXCOL',
                         column_position, SUBSTR(column_name,1,32),
                         CAST(NULL AS VARCHAR2(30)), CAST(NULL AS NUMBER),
                         CAST(NULL AS NUMBER), CAST(NULL AS NUMBER),
                         descend
                    FROM all_ind_columns 
                   UNION ALL
                  SELECT owner, table_name, constraint_name,
                         'CONSCOL', 
                         position, SUBSTR(column_name,1,32),
                         CAST(NULL AS VARCHAR2(30)), CAST(NULL AS NUMBER),
                         CAST(NULL AS NUMBER), CAST(NULL AS NUMBER),
                         CAST(NULL AS VARCHAR2(30))
                    FROM all_cons_columns) d
      WHERE o.owner=a.owner (+) AND o.object_name=a.table_name (+)
        AND o.owner=c.owner (+) AND o.object_name=c.table_name (+)
        AND o.owner=m.owner (+) AND o.object_name=m.mview_name (+)
        AND o.owner=t.owner (+) AND o.object_name=t.type_name (+)
        AND o.owner=l.owner (+) AND o.object_name=l.type_name (+)
        AND o.owner=s.owner (+) AND o.object_name=s.synonym_name (+)
        AND o.owner=q.sequence_owner (+) AND o.object_name=q.sequence_name (+)
        AND o.owner=i.owner (+) AND o.object_name=i.index_name (+)
        AND o.owner=r.owner (+) AND o.object_name=r.constraint_name (+)
        AND o.owner=b.owner (+) AND o.object_name=b.db_link (+)
        AND o.owner=d.owner (+) AND o.parent_object_name=d.parent_object_name (+)
             AND o.object_name =d.object_name (+)
             AND o.detail_type =d.detail_type (+)