CREATE MATERIALIZED VIEW "XTREME"."ORDERS_MONTH_TOTALS_YESTERDAY"
BUILD IMMEDIATE  
REFRESH COMPLETE  
NEXT TRUNC(sysdate+1)+1/24 
AS
Select extract(year from order_date) as order_year,
       extract(month from order_date) as order_month,
       sum(order_amount) as month_amount
  from orders
 group by extract(year from order_date),
       extract(month from order_date);


BEGIN
   DBMS_STATS.GATHER_TABLE_STATS(
     ownname => 'XTREME',
     tabname => 'ORDERS_MONTH_TOTALS_YESTERDAY');
END;

EXECUTE DBMS_MVIEW.REFRESH('XTREME.ORDERS_MONTH_TOTALS_YESTERDAY');

CREATE MATERIALIZED VIEW "XTREME"."ORDERS_MONTH_TOTALS_ONDEMAND"
BUILD IMMEDIATE  
REFRESH ON DEMAND 
AS
Select extract(year from order_date) as order_year,
       extract(month from order_date) as order_month,
       sum(order_amount) as month_amount
  from orders
 group by extract(year from order_date),
       extract(month from order_date);


EXECUTE DBMS_MVIEW.REFRESH('XTREME.ORDERS_MONTH_TOTALS_ONDEMAND');

CREATE MATERIALIZED VIEW LOG 
    ON "XTREME"."ORDERS" 
TABLESPACE "USERS" 
WITH ROWID, PRIMARY KEY ( ORDER_DATE, ORDER_AMOUNT), SEQUENCE  
INCLUDING NEW VALUES;

CREATE MATERIALIZED VIEW "XTREME"."ORDERS_MONTH_TOTALS_ONCOMMIT" 
BUILD IMMEDIATE  
REFRESH FAST 
ON COMMIT 
AS
Select extract(year from order_date) as order_year,
       extract(month from order_date) as order_month,
       sum(order_amount) as month_amount
  from orders
 group by extract(year from order_date),
       extract(month from order_date)

BEGIN
   DBMS_STATS.GATHER_TABLE_STATS(
     ownname => 'XTREME',
     tabname => 'ORDERS_MONTH_TOTALS_ONCOMMIT');
END;

CREATE MATERIALIZED VIEW "XTREME"."ORDERS_MONTH_TOTALS_REWRITE" 
BUILD IMMEDIATE  
REFRESH FAST 
ON DEMAND  
ENABLE QUERY REWRITE 
AS
Select extract(year from order_date) as order_year,
       extract(month from order_date) as order_month,
       sum(order_amount) as month_amount
  from orders
 group by extract(year from order_date),
       extract(month from order_date)

BEGIN
   DBMS_STATS.GATHER_TABLE_STATS(
     ownname => 'XTREME',
     tabname => 'ORDERS_MONTH_TOTALS_REWRITE');
END;